@@ -3,7 +3,7 @@ setMethod(f = "multisegout",signature = "CGHdata",
             
             M  = length(names(.Object@Y))
             
-            out = lapply(names(.Object@Y),FUN = function(m){
+            out = lapply(names(.Object@Y),FUN = function(m,y){
               i        = which(row.names(seg.rep) == m)
               k        = seg.rep[i,Kselect-M+1]
               rupt     = matrix(Inf,ncol = 2 , nrow= k)
@@ -12,12 +12,13 @@ setMethod(f = "multisegout",signature = "CGHdata",
                 rupt[1,1] = 1
               } else {
                 rupt[,1] = c(1,rupt[1:(k-1),2]+1)
-              }
-              mu       = data.frame(begin = rupt[,1],
-                end   = rupt[,2],
-                mean  = apply(rupt,1,FUN=function(z) mean(.Object@Y[[m]][z[1]:z[2]], na.rm=T)))
+              }			  
+	      resmean = meanRuptR_c(y[[m]], rupt[,2], k)
+              mu      = data.frame(begin = rupt[,1],
+              end     = rupt[,2],
+              mean    = resmean)
               invisible(mu)
-            })
+            },.Object@Y)
             names(out) = names(.Object@Y)
             invisible(out)
           })
