@@ -75,10 +75,10 @@ void LinProgDynMelange(double *sequence, int *lgSeq, int *nStep, double *res1, i
 	/* Lecture des données */
 	/* On stocke les données comme un liste de vecteurs */
 	//printf("ligne 11\n");
-	char c = 13;
+	
 	numlib_matrix_view matResult1 = numlib_matrix_view_array(res1, *nStep, *lgSeq);
 	numlib_matrix_set_all(&matResult1.matrix, NUMLIB_POSINF);
-	int i, j, k, l, iClasse;
+	int i, j, k;
 
 	
 	//printf("ligne 25\n");
